PRO RD1001,  HEADER, X1, V, IUN, IOERR
;
;  Procedure to read an independent variable mark (X1) and associated
;  primary variables (V) for FFI 1001.
;
;  Variable names are similar to those defined in the document 
;  "Format Specification For Data Exchange".
;
;Input:
;  HEADER = structure defined in RH1001.PRO.
;  IUN    = logical unit number for the ASCII exchange file.
;
;Output:
;  X1     = unbounded independent variable.
;  V      = floating array containing the primary variables.
;  IOERR  = I/O error code defined in IOERROR.
;
;History:
;  93-07-02 (SEG) Written.
;
;
IOERR = 0
ON_IOERROR, END_OF_FILE
;
;  Read independent variable mark and primary variables.
;  Scale primary variables and increment X1 counter.
;
F = FLTARR( HEADER.NV+1 )
READF, IUN, F
;
X1 = F(0)
V = FLTARR(HEADER.NV)
V = F(1:HEADER.NV) * HEADER.VSCAL(0:HEADER.NV-1)
HEADER.NX(0) = HEADER.NX(0) + 1
RETURN
;
END_OF_FILE:
IOERROR, IOERR
RETURN
END
