PRO RD1020,  HEADER, X1, A, V, IUN, IOERR
;
;  Procedure to read all data records associated with a particular
;  independent variable mark (X1) for FFI 1020.
;
;  Variable names are similar to those defined in the document 
;  "Format Specification For Data Exchange".
;
;Input:
;  HEADER = structure defined in RH1020.PRO.
;  IUN    = logical unit number for the ASCII exchange file.
;
;Output:
;  X1     = unbounded independent variable.
;  A      = auxiliary variables.
;  V      = floating array containing the primary variables.
;  IOERR  = I/O error code defined in IOERROR.
;
;History:
;  93-07-02 (SEG) Written.
;
;
IOERR = 0
ON_IOERROR, END_OF_FILE
;
;
;  Read independent variable mark and auxiliary variables; scale auxiliary
;  variables; increment counter for X1.
;
F = FLTARR( HEADER.NAUXV+1 )
READF, IUN, F
;
X1  = F(0)
X10 = X1(0)
HEADER.NX(0) = HEADER.NX(0) + 1
IF HEADER.NAUXV GT 0 THEN BEGIN
   A = FLTARR( HEADER.NAUXV )
   A = F(1:HEADER.NAUXV) * HEADER.ASCAL(0:HEADER.NAUXV-1)
ENDIF ELSE A=0.0
;
;  Read and scale primary variables; define remaining values of X1.
;
F = FLTARR( HEADER.NVPM(0) )
V = FLTARR( HEADER.NVPM(0),HEADER.NV )
FOR J=0,HEADER.NV-1 DO BEGIN
   READF, IUN, F
   V(*,J) = F * HEADER.VSCAL(J)
ENDFOR
X1 = X10 + HEADER.DX(0) * FINDGEN( HEADER.NVPM(0) )
HEADER.NX(0) = HEADER.NX(0) + HEADER.NVPM(0) - 1
RETURN
;
END_OF_FILE:
IOERROR, IOERR
RETURN
END
