PRO RD2010,  HEADER, X1, X2, A, V, IUN, IOERR
;
;  Procedure to read all data records associated with a particular
;  independent variable mark (X2) for FFI 2010.
;
;  Variable names are similar to those defined in the document 
;  "Format Specification For Data Exchange".
;
;Input:
;  HEADER = structure defined in RH2010.PRO.
;  IUN    = logical unit number for the ASCII exchange file.
;
;Output:
;  X1     = floating array containing the bounded independent variable values.
;  X2     = unbounded independent variable.
;  A      = auxiliary variables.
;  V      = floating array containing the primary variables.
;  IOERR  = I/O error code defined in IOERROR.
;
;History:
;  93-07-02 (SEG) Written.
;
;
IOERR = 0
ON_IOERROR, END_OF_FILE
;
;  Read independent variable mark and auxiliary variables; 
;  increment X2 counter; scale auxiliary variables.
;
F = FLTARR( HEADER.NAUXV+1 )
READF, IUN, F
;
X2 = F(0)
HEADER.NX(1) = HEADER.NX(1) + 1
IF HEADER.NAUXV GT 0 THEN BEGIN
   A = FLTARR( HEADER.NAUXV )
   A = F(1:HEADER.NAUXV) * HEADER.ASCAL(0:HEADER.NAUXV-1)
ENDIF ELSE A=0.0
;
;  Define X1.
;
IF HEADER.NXDEF(0) EQ HEADER.NX(0) THEN  $
   X1 = HEADER.XDEF(0:HEADER.NX(0)-1,0)  $
ELSE  $
   X1 = HEADER.XDEF(0,0) + HEADER.DX(0) * FINDGEN( HEADER.NX(0) )
;
;  Read and scale primary variables.
;
F = FLTARR( HEADER.NX(0) )
V = FLTARR( HEADER.NX(0),HEADER.NV )
FOR J=0,HEADER.NV-1 DO BEGIN
  READF, IUN, F
  V(*,J) = F * HEADER.VSCAL(J)
ENDFOR
RETURN
;
END_OF_FILE:
IOERROR, IOERR
RETURN
END
