PRO RD2160,  HEADER, X1, X2, A, CA, V, IUN, IOERR
;
;  Procedure to read all data records associated with a particular
;  independent variable mark (X2) for FFI 2160.
;
;  Variable names are similar to those defined in the document 
;  "Format Specification For Data Exchange".
;
;Input:
;  HEADER = structure defined in RH2160.PRO.
;  IUN    = logical unit number for the ASCII exchange file.
;
;Output:
;  X1     = floating array containing the bounded independent variable values.
;  X2     = unbounded independent variable (character string).
;  A      = numeric auxiliary variables.
;  CA     = character string auxiliary variables.
;  V      = floating array containing the primary variables.
;  IOERR  = I/O error code defined in IOERROR.
;
;History:
;  93-03-16 (SEG) Written.
;  93-07-12 (SEG) Changed auxiliary variable structure to arrays (AUXV-->A,CA).
;
;
IOERR = 0
ON_IOERROR, END_OF_FILE
;
;  Read independent variable mark and increment X2 counter.
;
X2 = ''
READF, IUN, X2
HEADER.NX(1) = HEADER.NX(1) + 1
;
;  Read and scale numeric auxiliary variables.
;
A = FLTARR(HEADER.NAUXV-HEADER.NAUXC)
READF, IUN, A
A = A * HEADER.ASCAL(0:HEADER.NAUXV-HEADER.NAUXC-1)
;
;  Store NX(0) in its allocated location in HEADER.
;
HEADER.NX(0) = FIX(A(0))
;
;  Read character string auxiliary variables.
;
IF HEADER.NAUXC GT 0 THEN BEGIN
   C  = ''
   CA = STRARR( HEADER.NAUXC )
   FOR J=0,HEADER.NAUXC-1 DO BEGIN
      READF, IUN, C
      CA(J) = C
   ENDFOR
ENDIF ELSE CA=''
;
;  Read bounded independent variable and primary variables.
;  Scale primary variables.
;
IF HEADER.NX(0) LT 1 OR HEADER.NX(0) GE HEADER.AMISS(0) THEN RETURN
F = FLTARR(HEADER.NV+1)
X1= FLTARR(HEADER.NX(0))
V = FLTARR( HEADER.NX(0),HEADER.NV )
FOR K=0,HEADER.NX(0)-1 DO BEGIN
  READF, IUN, F
  X1(K) = F(0)
  V(K,*) = F(1:HEADER.NV) * HEADER.VSCAL(0:HEADER.NV-1)
ENDFOR
RETURN
;
END_OF_FILE:
IOERROR, IOERR
RETURN
END
