PRO RD4010,  HEADER, X1, X2, X3, X4, A, V, IUN, IOERR
;
;  Procedure to read all data records associated with a particular
;  independent variable mark (X4) for FFI 4010.
;
;  Variable names are similar to those defined in the document 
;  "Format Specification For Data Exchange".
;
;Input:
;  HEADER = structure defined in RH4010.PRO.
;  IUN    = logical unit number for the ASCII exchange file.
;
;Output:
;  X1     = bounded independent variable values.
;  X2     = bounded independent variable values.
;  X3     = bounded independent variable values.
;  X4     = unbounded independent variable.
;  A      = auxiliary variables.
;  V      = floating array containing the primary variables.
;  IOERR  = I/O error code defined in IOERROR.
;
;History:
;  93-07-08 (SEG) Written.
;
;
IOERR = 0
ON_IOERROR, END_OF_FILE
;
;  Read independent variable mark and auxiliary variables; 
;  increment X4 counter; scale auxiliary variables.
;
F = FLTARR( HEADER.NAUXV+1 )
READF, IUN, F
;
X4 = F(0)
HEADER.NX(3) = HEADER.NX(3) + 1
IF HEADER.NAUXV GT 0 THEN BEGIN
   A = FLTARR( HEADER.NAUXV )
   A = F(1:HEADER.NAUXV) * HEADER.ASCAL(0:HEADER.NAUXV-1)
ENDIF ELSE A=0.0
;
;  Define X1.
;
IF HEADER.NXDEF(0) EQ HEADER.NX(0) THEN  $
   X1 = HEADER.XDEF(0:HEADER.NX(0)-1,0)  $
ELSE  $
   X1 = HEADER.XDEF(0,0) + HEADER.DX(0) * FINDGEN( HEADER.NX(0) )
;
;  Define X2.
;
IF HEADER.NXDEF(1) EQ HEADER.NX(1) THEN  $
   X2 = HEADER.XDEF(0:HEADER.NX(1)-1,1)  $
ELSE  $
   X2 = HEADER.XDEF(0,1) + HEADER.DX(1) * FINDGEN( HEADER.NX(1) )
;
;  Define X3.
;
IF HEADER.NXDEF(2) EQ HEADER.NX(2) THEN  $
   X3 = HEADER.XDEF(0:HEADER.NX(2)-1,2)  $
ELSE  $
   X3 = HEADER.XDEF(0,2) + HEADER.DX(2) * FINDGEN( HEADER.NX(2) )
;
;  Read and scale primary variables.
;
F = FLTARR( HEADER.NX(0) )
V = FLTARR( HEADER.NX(0),HEADER.NX(1),HEADER.NX(2),HEADER.NV )
FOR N=0,HEADER.NV-1 DO  $
   FOR K=0,HEADER.NX(2)-1 DO  $
      FOR J=0,HEADER.NX(1)-1 DO BEGIN
         READF, IUN, F
         V(*,J,K,N) = F * HEADER.VSCAL(N)
      ENDFOR
RETURN
;
END_OF_FILE:
IOERROR, IOERR
RETURN
END
