PRO RDFILE,  FILENAME, HEADER, IOERR, VA, AA, CAA, X1A, X2A, X3A, X4A
;
;  Procedure to read and return entire contents of an ASCII exchange data file,
;  assuming it has one of our standard exchange file formats.
;  RHEAD is called first to determine the FFI of the file and to read the
;  file header.  Then all data records are read using the routine which is
;  appropriate for the particular FFI.
;
;  Depending on the FFI, some of the returned variables may be undefined.
;  See the appropriate read routines and ADDIVM to determine the format of 
;  each of the returned variables.
;
;  The returned variables have similar names and function as those defined 
;  in the document entitled "Format Specification For Data Exchange", although
;  the indecies for some of the variables may be different than those in
;  the document.
;  
;
;Input:
;  FILENAME = path name for ASCII exchange file.
;
;Output:
;  HEADER = structure defined in appropriate file header read routine.
;  IOERR  = I/O error code defined in IOERROR.
;  VA     = array containing primary variable values.
;  AA     = array containing numeric auxiliary variable values.
;  CAA    = array containing character string auxilary variable values.
;  X1A    = array containing X1 independent variable values.
;  X2A    = array containing X2 independent variable values.
;  X3A    = array containing X3 independent variable values.
;  X4A    = array containing X4 independent variable values.
;
;History:
;  93-08-22 (SEG) Removed WHILE loop and speeded up 1001 read.
;  93-07-18 (SEG) Written.
;
;
OPENR, IUN, FILENAME, /GET_LUN
DATAEX_LIM_DEF,  LIMITS
RHEAD,  LIMITS, HEADER, IUN, IOERR
IF IOERR NE 0 THEN BEGIN
   STATUS = FSTAT( IUN )
   PRINT, !ERR_STRING
   STOP, '%% Error reading file ', STATUS.NAME
ENDIF
VA  = 0.0
AA  = 0.0
CAA = ''
X1A = 0.0
X2A = 0.0
X3A = 0.0
X4A = 0.0
CASE HEADER.FFI OF
   1001: BEGIN
            POINT_LUN, -IUN, BPOS
            CDUM = ''
            NLINES = 1L
            WHILE ( NOT EOF(IUN) ) DO BEGIN
               READF, IUN, CDUM
               NLINES = NLINES + 1L
            ENDWHILE
            POINT_LUN, IUN, BPOS
            TX1A   = FLTARR( NLINES(0) )
            TVA    = FLTARR( HEADER.NV, NLINES(0) )
            NR     = -1L
            REPEAT BEGIN
               RD1001,  HEADER, X1, V, IUN, IOERR
               IF IOERR EQ 0 THEN BEGIN
                  NR = NR + 1L
                  TX1A(NR)  = X1
                  TVA(*,NR) = V
               ENDIF
            ENDREP UNTIL IOERR NE 0
;melody fix
;           X1A = TX1A(0:HEADER.NX(0)-1)
x1a=tx1a(0:nlines(0)-1)
;           VA  = TVA(0:HEADER.NV-1, 0:HEADER.NX(0)-1 )
va=tva(0:header.nv-1,0:nlines(0)-1)
         END
   1010: REPEAT BEGIN
            RD1010,  HEADER, X1, A, V, IUN, IOERR
            IF IOERR EQ 0 THEN BEGIN
               ADDIVM,  X1A, X1
               ADDIVM,  VA, V
               ADDIVM,  AA, A
            ENDIF
         ENDREP UNTIL IOERR NE 0
  1020:  REPEAT BEGIN
            RD1020,  HEADER, X1, A, V, IUN, IOERR
            IF IOERR EQ 0 THEN BEGIN
               ADDIVM,  X1A, X1
               ADDIVM,  VA, V
               ADDIVM,  AA, A
            ENDIF
         ENDREP UNTIL IOERR NE 0
  2010:  REPEAT BEGIN
            RD2010,  HEADER, X1A, X2, A, V, IUN, IOERR
            IF IOERR EQ 0 THEN BEGIN
               ADDIVM,  X2A, X2
               ADDIVM,  VA, V
               ADDIVM,  AA, A
            ENDIF
         ENDREP UNTIL IOERR NE 0
  2110:  REPEAT BEGIN
            RD2110,  HEADER, X1, X2, A, V, IUN, IOERR
            IF IOERR EQ 0 THEN BEGIN
               ADDIVM,  X1A, X1
               ADDIVM,  X2A, X2
               ADDIVM,  VA, V
               ADDIVM,  AA, A
            ENDIF
         ENDREP UNTIL IOERR NE 0
  2160:  REPEAT BEGIN
            RD2160,  HEADER, X1, X2, A, CA, V, IUN, IOERR
            IF IOERR EQ 0 THEN BEGIN
               ADDIVM,  X1A, X1
               ADDIVM,  X2A, X2
               ADDIVM,  VA, V
               ADDIVM,  AA, A
               ADDIVM,  CAA, CA
            ENDIF
         ENDREP UNTIL IOERR NE 0
  2310:  REPEAT BEGIN
            RD2310,  HEADER, X1, X2, A, V, IUN, IOERR
            IF IOERR EQ 0 THEN BEGIN
            help,A,V,x1,x2
               ADDIVM,  X1A, X1
               ADDIVM,  X2A, X2
               ADDIVM,  VA, V
               ADDIVM,  AA, A
            ENDIF
         ENDREP UNTIL IOERR NE 0
  3010:  REPEAT BEGIN
            RD3010,  HEADER, X1A, X2A, X3, A, V, IUN, IOERR
            IF IOERR EQ 0 THEN BEGIN
               ADDIVM,  X3A, X3
               ADDIVM,  VA, V
               ADDIVM,  AA, A
            ENDIF
         ENDREP UNTIL IOERR NE 0
  4010:  REPEAT BEGIN
            RD4010,  HEADER, X1A, X2A, X3A, X4, A, V, IUN, IOERR
            IF IOERR EQ 0 THEN BEGIN
               ADDIVM,  X4A, X4
               ADDIVM,  VA, V
               ADDIVM,  AA, A
            ENDIF
         ENDREP UNTIL IOERR NE 0
  ELSE:  BEGIN
            PRINT, '%% Unknown FFI in RDFILE, FFI= ', HEADER.FFI
            STOP,  '%%  while reading file ', FILENAME
         END
ENDCASE
FREE_LUN, IUN
RETURN
END
